from os import environ

from dagster.core.events.log import EventLogEntry

MAXIMUM_EVENT_MESSAGE_CHARACTERS = environ.get(
    "DAGSTER_CLOUD_MAXIMUM_EVENT_MESSAGE_CHARACTERS", 50000
)


def truncate_event(
    event: EventLogEntry, maximum_length=MAXIMUM_EVENT_MESSAGE_CHARACTERS
) -> EventLogEntry:

    if len(event.user_message) > maximum_length:
        return event._replace(
            user_message=f"[TRUNCATED from {len(event.user_message)} characters to {MAXIMUM_EVENT_MESSAGE_CHARACTERS}] {event.user_message[:maximum_length]} [TRUNCATED]",
        )

    return event



from .process import ProcessUserCodeLauncher
from .user_code_launcher import (
    DEFAULT_SERVER_PROCESS_STARTUP_TIMEOUT,
    DagsterCloudUserCodeLauncher,
    UserCodeLauncherEntry,
)

DAGSTER_SANDBOX_PORT_ENV = "DAGSTER_SANDBOX_PORT"
DAGSTER_PROXY_HOSTNAME_ENV = "DAGSTER_PROXY_HOSTNAME"



from typing import Optional


def get_hardcoded_test_agent_token(organization_name) -> str:
    return f"agent:{organization_name}:hardcoded"


def get_hardcoded_test_user_token(organization_name, user_name) -> str:
    return f"user:{organization_name}:{user_name}"


def get_organization_name_from_agent_token(agent_token: str) -> Optional[str]:
    split_token = agent_token.split(":")
    # Legacy agent token format - organization must be specified in dagster.yaml
    if len(split_token) == 1:
        return None

    _type, organization, _identifier = split_token

    return organization
